<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;

class AuthController extends Controller
{
    public function login()
    {        
        return view('auth.login');
    }

    public function register_view()
    {
        return view('auth.register');
    }

    public function dashboard(Request $request)
    {
        return view('content.dashboard.dashboards-analytics');      
    }

    public function login_user(Request $request)
    {
        // validate data
        $request->validate([
            'email' => 'required|email',
            'password' => 'required'
        ]);
        
        
        // login code
        if(\Auth::attempt($request->only('email', 'password')))
        {          
            session(['Email' => $request->get('email')]);
            session()->flash('status', 'User Successfully Logged-in!');
            return redirect()->route('contacts.index');
        }

        session()->flash('status', 'incorrect username and password!');
        return redirect('/');
    }  

    public function register_user(Request $request)
    {
        // validate data
        $request->validate([
            'firstname' => 'required',
            'email' => 'required|unique:users|email',
            'password' => 'required|confirmed'
        ]);
     
        User::create([
            'firstname' => $request->firstname,
            'email' => $request->email,
            'password' => \Hash::make($request->password),
            'password_confirmation' => $request->password_confirmation
        ]);

        if(\Auth::attempt($request->only('email', 'password')))
        {
            session()->flash('status', 'User Register Successfully!');
            return redirect('/contacts');
        }

        session()->flash('status', 'User Not Register!');
        return redirect('register');

    }

    public function logout()
    {
        \Session::flush();
        \Auth::logout();

        return redirect('/login');
    }
}
