<?php

namespace App\Http\Controllers\disbursement;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use DB;
use App\Models\sanction\Sanction;
use App\Models\disbursement\Disbursement;
use App\Models\contact\Contact;
use App\Models\comment\Comment;
use App\Helpers\commentHelper as helper;

class DisbursementController extends Controller
{
  function __construct()
  {
    $this->middleware('permission:disbursement-list|disbursement-create|disbursement-edit|disbursement-delete', ['only' => ['index','show']]);
    $this->middleware('permission:disbursement-create', ['only' => ['create','store']]);
    $this->middleware('permission:disbursement-edit', ['only' => ['edit','update']]);
    $this->middleware('permission:disbursement-delete', ['only' => ['destroy']]);
  }
    //
    public function index()
    {
        //
        $data=Disbursement::paginate(10);
      return view('content.disbursement.index',compact('data'));
    }   

    public function create()
    {
      return view('content.disbursement.add-disbursement');
    }

    public function store(Request $request)
    {
      $request->validate([
        'client_id'=>'required|max:255',
        'sanction_id'=>'required|max:255',
        'disb_date'=>'required|max:255',
        'disb_amt'=>'required',
        'bank_id'=>'required',
        'pending_disb'=>'required|regex:/^([0-9\s\-\+\(\)]*)$/',
        'status'=>'required',
        'comments'=>'required',        
      ],
      [
        'client_id.required'=>'This field is required',
        'sanction_id.required'=>'This field is required',
        'disb_date.required'=>'This field is required',
        'disb_amt.required'=>'This field is required',
        'bank_id.required'=>'This field is required',
        'pending_disb.required'=>'This field is required',
        'pending_disb.regex'=>'The Format is Invalid',
        'status.required'=>'This field is required',
        'comments.required'=>'This field is required',        
      ]);
      
      $disbursement = Disbursement::create($request->all()); 
      Helper::addComment($disbursement->disb_id ,$request->comments, "disb");
      
      return redirect()->route('disbursements.index')->with('success','New Disbursement Added');
      
    }   
    public function show(Disbursement $disbursement)
    {
       
        $data=Contact::findorfail($disbursement->client_id);
        $data1=$data->tbl_hlsanction;
        $data2=$data->tbl_hldisbursement;
       
        $comData=Disbursement::findorfail($disbursement->disb_id);
        $comData1=$comData->tbl_hlcomments;  
        
       return view('content.disbursement.show',compact('comData','data','disbursement'));
    }

    public function edit(Disbursement $disbursement)
    {
        $disbdata=Contact::findorfail($disbursement->client_id);
        $data1=$disbdata->tbl_hlsanction;
        $data2=$disbdata->tbl_hldisbursement;    
        return view('content.disbursement.edit',compact('disbursement','disbdata'));
    }

    public function update(Request $request, Disbursement $disbursement)
    {
        $request->validate([
          'client_id'=>'required|max:255',
          'sanction_id'=>'required|max:255',
          'disb_date'=>'required|max:255',
          'disb_amt'=>'required',
          'bank_id'=>'required|',
          'pending_disb'=>'required|',         
          'status'=>'required', 
        ],
        [
          'client_id.required'=>'This field is required',
          'sanction_id.required'=>'This field is required',
          'disb_date.required'=>'This field is required',
          'disb_amt.required'=>'This field is required',
          'bank_id.required'=>'This field is required',
          'pending_disb.required'=>'This field is required',
          'status.required'=>'This field is required',  
                   
        ]);
        $disbursement->update($request->all());    
        return redirect()->route('disbursements.index')
                         ->with('success','Updated successfully');
                       
    }  
    
    public function changestatus(Request $request)
    {     
       $id = $request->id;
        $status = $request->status;   
       DB::table('tbl_hldisbursement')->where('disb_id',$id)->update([
        'disbursement_status'=>$status
       ]);
       $status="";
       $details=Disbursement::where('disb_id','=',$id)->get();
       foreach($details as $data)
       $status=$data->disbursement_status;
       
       return response()->json(
        [
          'success'=>true,
          'message'=>'updated',
          'status'=>$status
        ]
        );
    }
  
    function fetch(Request $request)
    {
        $select = $request->get('select');
        $value = $request->get('value');
        $dependent = $request->get('dependent');    
          $data = Sanction::select('sanction_id')
                                ->where($select, $value)
                                ->groupBy($dependent)
                                ->get();
          $output = '<option value="">Select ID</option>';
          foreach($data as $row)
          {
            $output .= '<option value="'.$row->$dependent.'">'.$row->$dependent.'</option>';
          }
          return response()->json($output);          
    }
     
}

